##  Typical Scenarios Where the Super/Cloud Admin Is Critical
### Receiving Workspace Provisioning Emails
SAP sends welcome messages, activation links, and SAP LeanIX workspace provisioning notifications to the super/cloud administrator. If this contact is not aware of their role or not actively monitoring their inbox, the provisioning process can be interrupted.
### Creating Necessary S-User IDs and Assigning Authorizations
After accessing a new SAP LeanIX workspace, the super/cloud administrators are the only users who can create new S-user IDs and assign authorizations to colleagues to enable broader access.
### Troubleshooting Access Issues
Missing authorizations or inability to log into SAP for Me or LeanIX usually require intervention from a super/cloud administrator.
